@@ -34,8 +34,9 @@ the effective destination project.
 
 '''
 
-import os, sys, json, subprocess, tempfile, logging, multiprocessing
+import os, sys, json, subprocess, tempfile, multiprocessing
 import dxpy
+from dxpy import logger
 
 NUM_CORES = multiprocessing.cpu_count()
 
@@ -82,11 +83,11 @@ def build(src_dir, parallel_build=True):
     if it exists (building with as many parallel tasks as there are CPUs on the
     system).
     """
-    logging.debug("Building in " + src_dir)
+    logger.debug("Building in " + src_dir)
     # TODO: use Gentoo or deb buildsystem
     config_script = os.path.join(src_dir, "configure")
     if os.path.isfile(config_script) and os.access(config_script, os.X_OK):
-        logging.debug("Running ./configure")
+        logger.debug("Running ./configure")
         try:
             subprocess.check_call([config_script])
         except subprocess.CalledProcessError as e:
@@ -98,7 +99,7 @@ def build(src_dir, parallel_build=True):
             make_shortcmd = "make -j%d" % (NUM_CORES,)
         else:
             make_shortcmd = "make"
-        logging.debug("Building with " + make_shortcmd)
+        logger.debug("Building with " + make_shortcmd)
         try:
             make_cmd = ["make", "-C", src_dir]
             if parallel_build:
@@ -143,7 +144,7 @@ def upload_resources(src_dir, project=None):
 
     resources_dir = os.path.join(src_dir, "resources")
     if os.path.exists(resources_dir) and len(os.listdir(resources_dir)) > 0:
-        logging.debug("Uploading in " + src_dir)
+        logger.debug("Uploading in " + src_dir)
 
         with tempfile.NamedTemporaryFile(suffix=".tar.gz") as tar_fh:
             subprocess.check_call(['tar', '-C', resources_dir, '-czf', tar_fh.name, '.'])
@@ -200,10 +201,10 @@ def upload_applet(src_dir, uploaded_resources, check_name_collisions=True, overw
 
     if check_name_collisions and not dry_run:
         destination_path = applet_spec['folder'] + ('/' if not applet_spec['folder'].endswith('/') else '') + applet_spec['name']
-        logging.debug("Checking for existing applet at " + destination_path)
+        logger.debug("Checking for existing applet at " + destination_path)
         for result in dxpy.find_data_objects(classname="applet", name=applet_spec["name"], folder=applet_spec['folder'], project=dest_project, recurse=False):
             if overwrite:
-                logging.info("Deleting applet %s" % (result['id']))
+                logger.info("Deleting applet %s" % (result['id']))
                 # TODO: test me
                 dxpy.DXProject(dest_project).remove_objects([result['id']])
             else:
@@ -220,7 +221,7 @@ def upload_applet(src_dir, uploaded_resources, check_name_collisions=True, overw
                 readme_filename = filename
                 break
         if readme_filename is None:
-            logging.warn("No description found; please supply one in README.md")
+            logger.warn("No description found; please supply one in README.md")
         else:
             with open(os.path.join(src_dir, readme_filename)) as fh:
                 applet_spec['description'] = fh.read()
@@ -290,7 +291,7 @@ def upload_applet(src_dir, uploaded_resources, check_name_collisions=True, overw
         print "*** DRY-RUN-- no applet was created ***"
         return None, None
 
-    applet_id = dxpy.api.appletNew(applet_spec)["id"]
+    applet_id = dxpy.api.applet_new(applet_spec)["id"]
 
     if "categories" in applet_spec:
         dxpy.DXApplet(applet_id, project=dest_project).add_tags(applet_spec["categories"])
@@ -305,7 +306,7 @@ def _create_or_update_version(app_name, version, app_spec, try_update=True):
     # This has a race condition since the app could have been created or
     # published since we last looked.
     try:
-        app_id = dxpy.api.appNew(app_spec)["id"]
+        app_id = dxpy.api.app_new(app_spec)["id"]
         return app_id
     except dxpy.exceptions.DXAPIError as e:
         # TODO: detect this error more reliably
@@ -314,7 +315,7 @@ def _create_or_update_version(app_name, version, app_spec, try_update=True):
             # The version number was already taken, so app/new doesn't work.
             # However, maybe it hasn't been published yet, so we might be able
             # to app-xxxx/update it.
-            app_describe = dxpy.api.appDescribe("app-" + app_name, alias=version)
+            app_describe = dxpy.api.app_describe("app-" + app_name, alias=version)
             if app_describe.get("published", 0) > 0:
                 return None
             return _update_version(app_name, version, app_spec, try_update=try_update)
@@ -328,7 +329,7 @@ def _update_version(app_name, version, app_spec, try_update=True):
     if not try_update:
         return None
     try:
-        app_id = dxpy.api.appUpdate("app-" + app_name, version, app_spec)["id"]
+        app_id = dxpy.api.app_update("app-" + app_name, version, app_spec)["id"]
         return app_id
     except dxpy.exceptions.DXAPIError as e:
         if e.name == 'InvalidState':
@@ -356,13 +357,13 @@ def create_app(applet_id, applet_name, src_dir, publish=False, set_default=False
         app_spec['version'] = version
         app_describe = None
         try:
-            # 404, which is rather likely in this appDescribe request
+            # 404, which is rather likely in this app_describe request
             # (the purpose of the request is to find out whether the
             # version of interest exists), would ordinarily cause this
             # request to be retried multiple times, introducing a
             # substantial delay. So we disable retrying here for this
             # request.
-            app_describe = dxpy.api.appDescribe("app-" + app_spec["name"], alias=version, always_retry=False)
+            app_describe = dxpy.api.app_describe("app-" + app_spec["name"], alias=version, always_retry=False)
         except dxpy.exceptions.DXAPIError as e:
             if e.name == 'ResourceNotFound':
                 pass
@@ -406,15 +407,15 @@ def create_app(applet_id, applet_name, src_dir, publish=False, set_default=False
 
     # Set categories appropriately.
     categories_to_set = app_spec.get("categories", [])
-    existing_categories = dxpy.api.appListCategories(app_id)['categories']
+    existing_categories = dxpy.api.app_list_categories(app_id)['categories']
     categories_to_add = set(categories_to_set).difference(set(existing_categories))
     categories_to_remove = set(existing_categories).difference(set(categories_to_set))
     if categories_to_add:
-        dxpy.api.appAddCategories(app_id, input_params={'categories': list(categories_to_add)})
+        dxpy.api.app_add_categories(app_id, input_params={'categories': list(categories_to_add)})
     if categories_to_remove:
-        dxpy.api.appRemoveCategories(app_id, input_params={'categories': list(categories_to_remove)})
+        dxpy.api.app_remove_categories(app_id, input_params={'categories': list(categories_to_remove)})
 
     if publish:
-        dxpy.api.appPublish(app_id, input_params={'makeDefault': set_default})
+        dxpy.api.app_publish(app_id, input_params={'makeDefault': set_default})
 
     return app_id
