@@ -82,18 +82,27 @@ parser.add_argument("--dx-toolkit-unstable-autodep", help="Auto-insert a dx-tool
 parser.add_argument("--dx-toolkit-autodep", help=argparse.SUPPRESS, action="store_const", dest="dx_toolkit_autodep", const="beta")
 parser.add_argument("--no-dx-toolkit-autodep", help="Do not auto-insert the dx-toolkit dependency if it's absent from the runSpec. See the documentation for more details.", action="store_false", dest="dx_toolkit_autodep")
 
+# TODO: remove this flag (once all calls to build_and_upload_locally are
+# in process
+#
 # --[no-]build (undocumented): perform the ./configure && make step
 parser.set_defaults(build_step=True)
 parser.add_argument("--build-step", help=argparse.SUPPRESS, action="store_true", dest="build_step")
 parser.add_argument("--no-build-step", help=argparse.SUPPRESS, action="store_false", dest="build_step")
 
+# TODO: remove this flag (once all calls to build_and_upload_locally are
+# in process
+#
 # --[no-]upload (undocumented): perform the actual upload
 parser.set_defaults(upload_step=True)
 parser.add_argument("--upload-step", help=argparse.SUPPRESS, action="store_true", dest="upload_step")
 parser.add_argument("--no-upload-step", help=argparse.SUPPRESS, action="store_false", dest="upload_step")
 
+# TODO: remove this flag (once all calls to build_and_upload_locally are
+# in process
+#
 # --[no-]json (undocumented): dumps the JSON describe of the app or
-# --applet that was created
+# applet that was created
 parser.set_defaults(json=False)
 parser.add_argument("--json", help=argparse.SUPPRESS, action="store_true", dest="json")
 parser.add_argument("--no-json", help=argparse.SUPPRESS, action="store_false", dest="json")
@@ -155,10 +164,9 @@ def _verify_app_source_dir(src_dir):
     if not os.path.exists(os.path.join(src_dir, "dxapp.json")):
         parser.error("Directory %s does not contain dxapp.json: not a valid DNAnexus app source directory" % src_dir)
 
-def _build_app_remote(mode, src_dir, destination=None, publish=False,
-                      dx_toolkit_autodep="auto", version_override=None,
-                      bill_to=None, version_autonumbering=True, update=True,
-                      parallel_build=True):
+def _build_app_remote(mode, src_dir, publish=False, destination_override=None,
+                      version_override=None, bill_to_override=None, dx_toolkit_autodep="auto",
+                      do_version_autonumbering=True, do_try_update=True, do_parallel_build=True):
     if mode == 'app':
         builder_app = 'app-tarball_app_builder'
     else:
@@ -166,43 +174,33 @@ def _build_app_remote(mode, src_dir, destination=None, publish=False,
 
     temp_dir = tempfile.mkdtemp()
 
-    # We have to resolve the correct dx-toolkit dependency type here and
-    # explicitly pass it into the interior call of dx-build-app, because
-    # within the execution environment of tarball_app(let)_builder,
-    # APISERVER_HOST is set to the address of the proxy (a 10.x.x.x
-    # address) and doesn't give us any information about whether we are
-    # talking to preprod.
+    # If dx_toolkit_autodep is "auto", We have to resolve the correct
+    # dx-toolkit dependency type here and explicitly pass it into the
+    # interior call of dx-build-app, because within the execution
+    # environment of tarball_app(let)_builder, APISERVER_HOST is set to
+    # the address of the proxy (a 10.x.x.x address) and doesn't give us
+    # any information about whether we are talking to preprod.
     if dx_toolkit_autodep == "auto":
         # "auto" (the default) means dx-toolkit (stable) on preprod and prod, and
         # dx-toolkit-beta on all other systems.
         if dxpy.APISERVER_HOST == "preprodapi.dnanexus.com" or dxpy.APISERVER_HOST == "api.dnanexus.com":
-            dx_toolkit_autodep_flag = "--dx-toolkit-stable-autodep"
+            dx_toolkit_autodep = "stable"
         else:
-            dx_toolkit_autodep_flag = "--dx-toolkit-beta-autodep"
-    elif dx_toolkit_autodep == "git":
-        dx_toolkit_autodep_flag = "--dx-toolkit-legacy-git-autodep"
-    elif dx_toolkit_autodep == "stable":
-        dx_toolkit_autodep_flag = "--dx-toolkit-stable-autodep"
-    elif dx_toolkit_autodep == "beta":
-        dx_toolkit_autodep_flag = "--dx-toolkit-beta-autodep"
-    elif dx_toolkit_autodep == "unstable":
-        dx_toolkit_autodep_flag = "--dx-toolkit-unstable-autodep"
-    elif dx_toolkit_autodep == False:
-        dx_toolkit_autodep_flag = "--no-dx-toolkit-autodep"
+            dx_toolkit_autodep = "beta"
 
-    extra_flags = [dx_toolkit_autodep_flag]
+    build_options = {'dx_toolkit_autodep': dx_toolkit_autodep}
 
     # These flags are basically passed through verbatim.
     if version_override:
-        extra_flags.extend(['--version', version_override])
-    if bill_to:
-        extra_flags.extend(['--bill-to', bill_to])
-    if not version_autonumbering:
-        extra_flags.append('--no-version-autonumbering')
-    if not update:
-        extra_flags.append('--no-update')
-    if not parallel_build:
-        extra_flags.append('--no-parallel-build')
+        build_options['version_override'] = version_override
+    if bill_to_override:
+        build_options['bill_to_override'] = bill_to_override
+    if not do_version_autonumbering:
+        build_options['do_version_autonumbering'] = False
+    if not do_try_update:
+        build_options['do_try_update'] = False
+    if not do_parallel_build:
+        build_options['do_parallel_build'] = False
 
     using_temp_project_for_remote_build = False
 
@@ -219,19 +217,16 @@ def _build_app_remote(mode, src_dir, destination=None, publish=False,
         # 2. Make the output folder FOLDER
         # 3. Supply --destination=NAME to the interior call of dx-build-applet.
         build_project_id = dxpy.WORKSPACE_ID
-        if destination:
-            build_project_id, dest_folder, dest_applet_name = parse_destination(destination)
+        if destination_override:
+            build_project_id, dest_folder, dest_applet_name = parse_destination(destination_override)
         if build_project_id is None:
             parser.error("Can't create an applet without specifying a destination project; please use the -d/--destination flag to explicitly specify a project")
         if dest_applet_name:
-            # TODO: escape this correctly, or find a way of passing the
-            # extra_flags that doesn't get screwed up by names that have
-            # spaces in them.
-            extra_flags.extend(['--destination', '/' + dest_applet_name])
+            build_options['destination_override'] = '/' + dest_applet_name
 
     elif mode == "app":
         using_temp_project_for_remote_build = True
-        build_project_id = dxpy.api.projectNew({"name": "dx-build-app --remote temporary project"})["id"]
+        build_project_id = dxpy.api.project_new({"name": "dx-build-app --remote temporary project"})["id"]
 
     try:
         # Resolve relative paths and symlinks here so we have something
@@ -288,10 +283,9 @@ def _build_app_remote(mode, src_dir, destination=None, publish=False,
                                              wait_on_close=True, show_progress=True)
 
         try:
-            extra_flags_str = " ".join(pipes.quote(s) for s in extra_flags)
             input_hash = {
                 "input_file": dxpy.dxlink(remote_file),
-                "extra_flags": extra_flags_str
+                "build_options": build_options
                 }
             if mode == 'app':
                 input_hash["publish"] = publish
@@ -302,7 +296,7 @@ def _build_app_remote(mode, src_dir, destination=None, publish=False,
                 }
             if dest_folder:
                 api_options["folder"] = dest_folder
-            app_run_result = dxpy.api.appRun(builder_app, input_params=api_options)
+            app_run_result = dxpy.api.app_run(builder_app, input_params=api_options)
             job_id = app_run_result["id"]
             print "Started builder job %s" % (job_id,)
             subprocess.check_call(["dx", "watch", job_id])
@@ -311,7 +305,7 @@ def _build_app_remote(mode, src_dir, destination=None, publish=False,
                 dxpy.DXProject(build_project_id).remove_objects([remote_file.get_id()])
     finally:
         if using_temp_project_for_remote_build:
-            dxpy.api.projectDestroy(build_project_id)
+            dxpy.api.project_destroy(build_project_id)
         shutil.rmtree(temp_dir)
 
     return
@@ -330,7 +324,7 @@ def build_and_upload_locally(src_dir, mode, overwrite=False, publish=False, dest
         working_project, override_folder, override_applet_name = parse_destination(destination_override)
     elif mode == "app" and use_temp_build_project and not dry_run:
         # Create a temp project
-        working_project = dxpy.api.projectNew({"name": "Temporary build project for dx-build-app"})["id"]
+        working_project = dxpy.api.project_new({"name": "Temporary build project for dx-build-app"})["id"]
         print >> sys.stderr, "Created temporary project %s to build in" % (working_project,)
         using_temp_project = True
 
@@ -341,8 +335,8 @@ def build_and_upload_locally(src_dir, mode, overwrite=False, publish=False, dest
         with open(os.path.join(src_dir, "dxapp.json")) as app_desc:
             try:
                 app_json = json.load(app_desc)
-            except:
-                parser.error("Could not parse dxapp.json file as valid JSON")
+            except Exception as e:
+                raise dxpy.app_builder.AppBuilderException("Could not parse dxapp.json file as JSON: " + e.message)
 
         if "buildOptions" in app_json:
             if app_json["buildOptions"].get("dx_toolkit_autodep") == False:
@@ -383,7 +377,7 @@ def build_and_upload_locally(src_dir, mode, overwrite=False, publish=False, dest
             if not using_temp_project:
                 objects_to_delete = [dxpy.get_dxlink_ids(bundled_resource_obj['id'])[0] for bundled_resource_obj in bundled_resources]
                 if objects_to_delete:
-                    dxpy.api.projectRemoveObjects(dxpy.app_builder.get_destination_project(src_dir, project=working_project),
+                    dxpy.api.project_remove_objects(dxpy.app_builder.get_destination_project(src_dir, project=working_project),
                                                   input_params={"objects": objects_to_delete})
             raise
 
@@ -411,7 +405,7 @@ def build_and_upload_locally(src_dir, mode, overwrite=False, publish=False, dest
                                                  try_versions=try_versions,
                                                  try_update=do_try_update)
 
-            app_describe = dxpy.api.appDescribe(app_id)
+            app_describe = dxpy.api.app_describe(app_id)
 
             if publish:
                 print >> sys.stderr, "Uploaded and published app %s/%s (%s) successfully" % (app_describe["name"], app_describe["version"], app_id)
@@ -423,14 +417,14 @@ def build_and_upload_locally(src_dir, mode, overwrite=False, publish=False, dest
             return app_describe if return_object_dump else None
 
         elif mode == "applet":
-            return dxpy.api.appletDescribe(applet_id) if return_object_dump else None
+            return dxpy.api.applet_describe(applet_id) if return_object_dump else None
         else:
             raise dxpy.app_builder.AppBuilderException("Unrecognized mode %r" % (mode,))
 
     finally:
         # Clean up after ourselves.
         if using_temp_project:
-            dxpy.api.projectDestroy(working_project)
+            dxpy.api.project_destroy(working_project)
 
 
 def main(**kwargs):
@@ -510,15 +504,15 @@ def main(**kwargs):
         if args.version_override:
             more_kwargs['version_override'] = args.version_override
         if args.bill_to:
-            more_kwargs['bill_to'] = args.bill_to
+            more_kwargs['bill_to_override'] = args.bill_to
         if not args.version_autonumbering:
-            more_kwargs['version_autonumbering'] = False
+            more_kwargs['do_version_autonumbering'] = False
         if not args.update:
-            more_kwargs['update'] = False
+            more_kwargs['do_try_update'] = False
         if not args.parallel_build:
-            more_kwargs['parallel_build'] = False
+            more_kwargs['do_parallel_build'] = False
 
-        return _build_app_remote(args.mode, args.src_dir, destination=args.destination, publish=args.publish, dx_toolkit_autodep=args.dx_toolkit_autodep, **more_kwargs)
+        return _build_app_remote(args.mode, args.src_dir, destination_override=args.destination, publish=args.publish, dx_toolkit_autodep=args.dx_toolkit_autodep, **more_kwargs)
 
 
 if __name__ == '__main__':
