@@ -22,6 +22,7 @@ import random
 import sys
 import re
 import argparse
+import subprocess
 
 import magic
 
@@ -357,7 +358,7 @@ def unpack(input):
 
         try:
             subprocess.check_call(" ".join([test_util, "-t", input]), shell=True)
-        except:
+        except subprocess.CalledProcessError:
             raise dxpy.AppError("File failed integrity check by "+uncomp_util+".  Compressed file is corrupted.")
 
     # with that in hand, unzip file.  If we find a tar archive then exit with error.
@@ -376,7 +377,7 @@ def unpack(input):
     try:
         subprocess.check_call(" ".join([uncomp_util, "--stdout", input, ">", "uncompressed.gff"]), shell=True)
         return "uncompressed.gff"
-    except:
+    except subprocess.CalledProcessError:
         raise dxpy.AppError("Unable to open compressed input for reading")
 
 
